@@ -23,7 +23,10 @@ class CellRendererCombo(gtk.CellRendererCombo):
         if not self.props.visible:
             return
         if not event:
-            event = gtk.gdk.Event(gtk.keysyms.Tab)
+            if hasattr(gtk.gdk.Event, 'new'):
+                event = gtk.gdk.Event.new(gtk.gdk.KEY_PRESS)
+            else:
+                event = gtk.gdk.Event(gtk.gdk.KEY_PRESS)
         editable = gtk.CellRendererCombo.do_start_editing(self, event, widget,
             path, background_area, cell_area, flags)
         return selection_shortcuts(editable)
