@@ -293,13 +293,11 @@ def request_server(server_widget):
 
 
 def get_toplevel_window():
-    windows = [x for x in gtk.window_list_toplevels()
-        if x.get_window() and x.props.visible
-        and x.props.type == gtk.WINDOW_TOPLEVEL]
-    trans2windows = dict((x.get_transient_for(), x) for x in windows)
-    for window in set(windows) - set(trans2windows.iterkeys()):
-        return window
-    return trans2windows[None]
+    for window in gtk.window_list_toplevels():
+        if window.is_active() and window.props.type == gtk.WINDOW_TOPLEVEL:
+            return window
+    from tryton.gui.main import Main
+    return Main.get_main().window
 
 
 def get_sensible_widget(window):
@@ -1001,21 +999,13 @@ def process_exception(exception, *args, **kwargs):
             name, msg, description = exception.args
             res = userwarning(description, msg)
             if res in ('always', 'ok'):
-                args2 = ('model', 'res.user.warning', 'create', [{
+                RPCExecute('model', 'res.user.warning', 'create', [{
                             'user': rpc._USER,
                             'name': name,
                             'always': (res == 'always'),
-                            }], rpc.CONTEXT)
-                try:
-                    rpc_execute(*args2)
-                except TrytonServerError, exception:
-                    process_exception(exception, *args2)
-                if args:
-                    try:
-                        return rpc_execute(*args)
-                    except TrytonServerError, exception:
-                        return process_exception(exception, *args,
-                            rpc_execute=rpc_execute)
+                            }],
+                    process_exception=False)
+                return rpc_execute(*args)
         elif exception.faultCode == 'UserError':
             msg, description = exception.args
             warning(description, msg)
@@ -1024,36 +1014,27 @@ def process_exception(exception, *args, **kwargs):
                 if concurrency(args[1], args[3][0], args[5]):
                     if '_timestamp' in args[5]:
                         del args[5]['_timestamp']
-                    try:
-                        return rpc_execute(*args)
-                    except TrytonServerError, exception:
-                        return process_exception(exception, *args,
-                            rpc_execute=rpc_execute)
+                    return rpc_execute(*args)
             else:
                 message(_('Concurrency Exception'), msg_type=gtk.MESSAGE_ERROR)
         elif (exception.faultCode.startswith('403')
                 or exception.faultCode.startswith('401')):
             from tryton.gui.main import Main
-            if not PLOCK.acquire(False):
-                return
-            language = CONFIG['client.lang']
-            func = lambda parameters: rpc.login(
-                rpc._HOST, rpc._PORT, rpc._DATABASE, rpc._USERNAME, parameters,
-                language)
-            try:
-                Login(func)
-            except TrytonError, exception:
-                if exception.faultCode == 'QueryCanceled':
-                    Main.get_main().sig_quit()
-                raise
-            finally:
-                PLOCK.release()
-            if args:
+            if PLOCK.acquire(False):
+                language = CONFIG['client.lang']
+                func = lambda parameters: rpc.login(
+                    rpc._HOST, rpc._PORT, rpc._DATABASE, rpc._USERNAME,
+                    parameters, language)
                 try:
+                    Login(func)
+                except TrytonError, exception:
+                    if exception.faultCode == 'QueryCanceled':
+                        Main.get_main().sig_quit()
+                    raise
+                finally:
+                    PLOCK.release()
+                if args:
                     return rpc_execute(*args)
-                except TrytonServerError, exception:
-                    return process_exception(exception, *args,
-                        rpc_execute=rpc_execute)
         else:
             error(exception.faultCode, exception.faultString)
     else:
@@ -1192,14 +1173,19 @@ class RPCProgress(object):
         if self.parent and self.parent.get_window():
             self.parent.get_window().set_cursor(None)
 
+        if self.exception and self.process_exception_p:
+            def rpc_execute(*args):
+                return RPCProgress('execute', args).run(
+                    self.process_exception_p, self.callback)
+            try:
+                return process_exception(
+                    self.exception, *self.args, rpc_execute=rpc_execute)
+            except RPCException, exception:
+                self.exception = exception
+
         def return_():
             if self.exception:
-                if self.process_exception_p:
-                    def rpc_execute(*args):
-                        return RPCProgress('execute',
-                            args).run(self.process_exception_p, self.callback)
-                    return process_exception(self.exception, *self.args,
-                        rpc_execute=rpc_execute)
+                raise self.exception
             else:
                 return self.res
 
