@@ -38,6 +38,8 @@ else:
         def set_placeholder_text(self, text):
             self._placeholder = text
             if not self.has_focus():
+                if self._default:
+                    super(PlaceholderEntry, self).set_text('')
                 self._focus_out()
 
         def get_text(self):
@@ -65,6 +67,8 @@ if __name__ == '__main__':
 
     placeholder_entry = PlaceholderEntry()
     placeholder_entry.set_placeholder_text('Placeholder')
+    # Set twice to check placeholder does not become text
+    placeholder_entry.set_placeholder_text('Placeholder')
     vbox.pack_start(placeholder_entry)
 
     win.show_all()
