@@ -18,7 +18,10 @@ _ = gettext.gettext
 
 def get_config_dir():
     if os.name == 'nt':
-        return os.path.join(os.environ['APPDATA'], '.config', 'tryton',
+        appdata = os.environ['APPDATA']
+        if not isinstance(appdata, unicode):
+            appdata = unicode(appdata, sys.getfilesystemencoding())
+        return os.path.join(appdata, '.config', 'tryton',
                 __version__.rsplit('.', 1)[0])
     return os.path.join(os.environ['HOME'], '.config', 'tryton',
             __version__.rsplit('.', 1)[0])
@@ -36,13 +39,10 @@ class ConfigManager(object):
         self.defaults = {
             'login.profile': demo_server,
             'login.login': 'demo',
-            'login.server': demo_server,
-            'login.port': '8000',
+            'login.host': demo_server,
             'login.db': demo_database,
             'login.expanded': False,
-            'tip.autostart': False,
-            'tip.position': 0,
-            'form.toolbar': True,
+            'client.title': 'Tryton',
             'client.default_width': 900,
             'client.default_height': 750,
             'client.modepda': False,
@@ -63,9 +63,7 @@ class ConfigManager(object):
             'menu.expanded': True,
         }
         self.config = {}
-        self.options = {
-            'login.host': True
-        }
+        self.options = {}
         self.arguments = []
 
     def parse(self):
@@ -84,10 +82,8 @@ class ConfigManager(object):
                 "DEBUG, INFO, WARNING, ERROR, CRITICAL"))
         parser.add_option("-u", "--user", dest="login",
                 help=_("specify the login user"))
-        parser.add_option("-p", "--port", dest="port",
-                help=_("specify the server port"))
-        parser.add_option("-s", "--server", dest="server",
-                help=_("specify the server hostname"))
+        parser.add_option("-s", "--server", dest="host",
+                help=_("specify the server hostname:port"))
         opt, self.arguments = parser.parse_args()
 
         if len(self.arguments) > 1:
@@ -115,7 +111,7 @@ class ConfigManager(object):
                 opt.log_level = 'ERROR'
         logging.getLogger().setLevel(loglevels[opt.log_level.upper()])
 
-        for arg in ('login', 'port', 'server'):
+        for arg in ['login', 'host']:
             if getattr(opt, arg):
                 self.options['login.' + arg] = getattr(opt, arg)
 
@@ -132,7 +128,7 @@ class ConfigManager(object):
             configparser.write(open(self.rcfile, 'wb'))
         except IOError:
             logging.getLogger(__name__).warn(
-                _('Unable to write config file %s!')
+                _('Unable to write config file %s.')
                 % (self.rcfile,))
             return False
         return True
@@ -163,17 +159,11 @@ class ConfigManager(object):
             self.defaults.get(key)))
 
 CONFIG = ConfigManager()
-CURRENT_DIR = unicode(os.path.dirname(__file__),
-    sys.getfilesystemencoding())
-if (os.name == 'nt' and hasattr(sys, 'frozen')
-        and os.path.basename(sys.executable) == 'tryton.exe'):
-    CURRENT_DIR = os.path.dirname(unicode(sys.executable,
-        sys.getfilesystemencoding()))
-elif (os.name == 'mac'
-        or (hasattr(os, 'uname') and os.uname()[0] == 'Darwin')):
-    resources = os.path.join(os.path.dirname(sys.argv[0]), '..', 'Resources')
-    if os.path.isdir(resources):
-        CURRENT_DIR = resources
+CURRENT_DIR = os.path.dirname(__file__)
+if hasattr(sys, 'frozen'):
+    CURRENT_DIR = os.path.dirname(sys.executable)
+if not isinstance(CURRENT_DIR, unicode):
+    CURRENT_DIR = unicode(CURRENT_DIR, sys.getfilesystemencoding())
 
 PIXMAPS_DIR = os.path.join(CURRENT_DIR, 'data', 'pixmaps', 'tryton')
 if not os.path.isdir(PIXMAPS_DIR):
