@@ -36,7 +36,7 @@ class Attachment(WinForm):
             resource = self.screen.group.fields['resource']
             for record in self.screen.group:
                 resource.set_client(record, self.resource)
-            self.screen.group.save()
+            self.screen.save_current()
         if self.attachment_callback:
             self.attachment_callback()
 
@@ -47,6 +47,7 @@ class Attachment(WinForm):
         new_record = self.screen.new()
         file_name = os.path.basename(urlparse.urlparse(uri).path)
         name_field.set_client(new_record, file_name)
+        uri = urllib.unquote(uri)
         uri = uri.decode('utf-8').encode(sys.getfilesystemencoding())
         data_field.set_client(new_record, urllib.urlopen(uri).read())
         self.screen.display()
