@@ -11,7 +11,7 @@ from . import View
 try:
     from .calendar_gtk.calendar_ import Calendar_
     from .calendar_gtk.toolbar import Toolbar
-except ImportError:
+except ImportError, e:
     Calendar_ = None
     Toolbar = None
 
@@ -82,8 +82,8 @@ class ViewCalendar(View):
         self.screen.switch_view('form')
 
     def on_event_released(self, goocalendar, event):
-        dtstart = self.attributes.get('dtstart')
-        dtend = self.attributes.get('dtend') or dtstart
+        dtstart = self.attributes['dtstart']
+        dtend = self.attributes.get('dtend')
         record = event.record
         group = record.group
         previous_start = record[dtstart].get(record)
@@ -93,12 +93,12 @@ class ViewCalendar(View):
             new_start = event.start.date()
             new_end = event.end.date() if event.end else None
         if previous_start <= new_start:
-            if new_end:
+            if dtend:
                 group.fields[dtend].set_client(record, new_end)
             group.fields[dtstart].set_client(record, new_start)
         else:
             group.fields[dtstart].set_client(record, new_start)
-            if new_end:
+            if dtend:
                 group.fields[dtend].set_client(record, new_end)
         goocalendar.select(new_start)
         record.save()
@@ -141,13 +141,6 @@ class ViewCalendar(View):
     @goocalendar_required
     def display(self):
         self.widgets['goocalendar'].display(self.screen.group)
-        gtkcal = self.widgets['toolbar'].gtkcal
-        if gtkcal and not gtkcal.is_drawable():
-            import goocanvas
-            # disable gtk.Calendar if it is not drawable anymore
-            self.widgets['toolbar'].gtkcal_item.set_property('visibility',
-                goocanvas.ITEM_INVISIBLE)
-            self.widgets['toolbar'].current_page.set_active(False)
 
     def set_cursor(self, new=False, reset_view=True):
         pass
