@@ -1,5 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
+import datetime
+
 import gtk
 import gettext
 
@@ -8,6 +10,7 @@ import gobject
 from .widget import Widget
 from tryton.common.datetime_ import (Date as DateEntry, Time as TimeEntry,
     DateTime as DateTimeEntry, add_operators)
+from tryton.common.widget_style import set_widget_style
 from tryton.config import CONFIG
 
 _ = gettext.gettext
@@ -34,6 +37,7 @@ class Date(Widget):
 
     def _set_editable(self, value):
         self.entry.set_editable(value)
+        set_widget_style(self.entry, value)
         self.entry.set_icon_sensitive(gtk.ENTRY_ICON_SECONDARY, value)
 
     def _readonly_set(self, value):
@@ -43,10 +47,17 @@ class Date(Widget):
         else:
             self.widget.unset_focus_chain()
 
+    @classmethod
+    def cast(cls, value):
+        if isinstance(value, datetime.datetime):
+            value = value.date()
+        return value
+
     @property
     def modified(self):
         if self.record and self.field:
-            return self.field.get_client(self.record) != self.entry.props.value
+            field_value = self.cast(self.field.get_client(self.record))
+            return field_value != self.entry.props.value
         return False
 
     def sig_key_press(self, widget, event):
@@ -62,7 +73,7 @@ class Date(Widget):
         if field and record:
             format_ = field.date_format(record)
         else:
-            format_ = self.view.screen.context.get('date_format', '%x')
+            format_ = self.view.screen.date_format
         self.entry.props.format = format_
 
     def display(self, record, field):
@@ -84,6 +95,12 @@ class Time(Date):
     def _set_editable(self, value):
         self.entry.set_sensitive(value)
 
+    @classmethod
+    def cast(cls, value):
+        if isinstance(value, datetime.datetime):
+            value = value.time()
+        return value
+
     @property
     def real_entry(self):
         return self.entry.get_child()
@@ -126,10 +143,15 @@ class DateTime(Date):
             child.connect('focus-out-event', lambda x, y: self._focus_out())
         self.widget.pack_start(self.entry, expand=False, fill=False)
 
+    @classmethod
+    def cast(cls, value):
+        return value
+
     def _set_editable(self, value):
         for child in self.entry.get_children():
             if isinstance(child, gtk.Entry):
                 child.set_editable(value)
+                set_widget_style(child, value)
                 child.set_icon_sensitive(gtk.ENTRY_ICON_SECONDARY, value)
             elif isinstance(child, gtk.ComboBoxEntry):
                 child.set_sensitive(value)
@@ -139,7 +161,7 @@ class DateTime(Date):
             date_format = field.date_format(record)
             time_format = field.time_format(record)
         else:
-            date_format = self.view.screen.context.get('date_format', '%x')
+            date_format = self.view.screen.date_format
             time_format = '%X'
         self.entry.props.date_format = date_format
         self.entry.props.time_format = time_format
