@@ -28,6 +28,10 @@ class Char(Widget, TranslateMixin, PopdownMixin):
             focus_entry = self.entry.get_child()
             self.set_popdown([], self.entry)
             self.entry.connect('changed', self.changed)
+            self.entry.connect('move-active', self._move_active)
+            self.entry.connect(
+                'scroll-event',
+                lambda c, e: c.emit_stop_by_name('scroll-event'))
         else:
             self.entry = gtk.Entry()
             focus_entry = self.entry
@@ -138,15 +142,20 @@ class Char(Widget, TranslateMixin, PopdownMixin):
                 reset_position(child)
             self.entry.handler_unblock_by_func(self.changed)
 
+    def _move_active(self, combobox, scroll_type):
+        if not combobox.get_child().get_editable():
+            combobox.emit_stop_by_name('move-active')
+
     def _readonly_set(self, value):
         sensitivity = {True: gtk.SENSITIVITY_OFF, False: gtk.SENSITIVITY_AUTO}
         super(Char, self)._readonly_set(value)
         if self.autocomplete:
-            self.entry.get_child().set_editable(not value)
+            entry_editable = self.entry.get_child()
             self.entry.set_button_sensitivity(sensitivity[value])
         else:
-            self.entry.set_editable(not value)
-        set_widget_style(self.entry, not value)
+            entry_editable = self.entry
+        entry_editable.set_editable(not value)
+        set_widget_style(entry_editable, not value)
         if value and CONFIG['client.fast_tabbing']:
             self.widget.set_focus_chain([])
         else:
