@@ -3,6 +3,7 @@
 # This code is inspired by the pycha project
 # (http://www.lorenzogil.com/projects/pycha/)
 import gtk
+
 from functools import reduce
 from tryton.common import hex2rgb, generateColorscheme, \
         COLOR_SCHEMES, datetime_strftime
@@ -16,6 +17,8 @@ import cairo
 from tryton.action import Action
 from tryton.gui.window import Window
 
+gtk_version = getattr(gtk, 'get_major_version', lambda: 2)()
+
 
 class Popup(object):
 
@@ -34,7 +37,8 @@ class Popup(object):
 
     def set_position(self, widget, x, y):
         widget_x, widget_y = widget.window.get_origin()
-        width, height = widget.window.get_size()
+        allocation = widget.get_allocation()
+        width, height = allocation.width, allocation.height
         popup_width, popup_height = self.win.get_size()
         if x < popup_width // 2:
             x = popup_width // 2
@@ -68,7 +72,10 @@ class Popup(object):
 class Graph(gtk.DrawingArea):
     'Graph'
 
-    __gsignals__ = {"expose-event": "override"}
+    if gtk_version == 2:
+        __gsignals__ = {"expose-event": "override"}
+    else:
+        __gsignals__ = {"draw": "override"}
 
     def __init__(self, view, xfield, yfields):
         super(Graph, self).__init__()
@@ -103,23 +110,36 @@ class Graph(gtk.DrawingArea):
     def leave(self, widget, event):
         self.popup.hide()
 
-    # Handle the expose-event by drawing
-    def do_expose_event(self, event):
+    if gtk_version == 2:
+        # Handle the expose-event by drawing
+        def do_expose_event(self, event):
 
-        # Create the cairo context
-        cr = self.window.cairo_create()
+            # Create the cairo context
+            cr = self.window.cairo_create()
 
-        # Restrict Cairo to the exposed area; avoid extra work
-        cr.rectangle(event.area.x, event.area.y,
-                event.area.width, event.area.height)
-        cr.clip()
+            # Restrict Cairo to the exposed area; avoid extra work
+            cr.rectangle(event.area.x, event.area.y,
+                    event.area.width, event.area.height)
+            cr.clip()
 
-        self.updateArea(cr, *self.window.get_size())
-        self.drawBackground(cr, *self.window.get_size())
-        self.drawLines(cr, *self.window.get_size())
-        self.drawGraph(cr, *self.window.get_size())
-        self.drawAxis(cr, *self.window.get_size())
-        self.drawLegend(cr, *self.window.get_size())
+            self.updateArea(cr, *self.window.get_size())
+            self.drawBackground(cr, *self.window.get_size())
+            self.drawLines(cr, *self.window.get_size())
+            self.drawGraph(cr, *self.window.get_size())
+            self.drawAxis(cr, *self.window.get_size())
+            self.drawLegend(cr, *self.window.get_size())
+    else:
+        def do_draw(self, cr):
+            cr = self.window.cairo_create()
+            width = self.get_allocated_width()
+            height = self.get_allocated_height()
+
+            self.updateArea(cr, width, height)
+            self.drawBackground(cr, width, height)
+            self.drawLines(cr, width, height)
+            self.drawGraph(cr, width, height)
+            self.drawAxis(cr, width, height)
+            self.drawLegend(cr, width, height)
 
     def export_png(self, filename, width, height):
         surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, width, height)
@@ -203,7 +223,7 @@ class Graph(gtk.DrawingArea):
 
     def drawAxis(self, cr, width, height):
         cr.set_source_rgb(*hex2rgb('#000000'))
-        cr.set_line_width(1.5)
+        cr.set_line_width(0.5)
 
         # Y axis
         def drawYLabel(h, label):
@@ -272,9 +292,10 @@ class Graph(gtk.DrawingArea):
             x2 = x1 + self.area.w
 
         cr.save()
-        cr.set_source_rgb(*hex2rgb('#808080'))
-        cr.set_line_width(1.5)
+        cr.set_source_rgb(*hex2rgb('#A0A0A0'))
+        cr.set_line_width(0.3)
         cr.new_path()
+        cr.set_dash([5.0, 4.0])
         cr.move_to(x1, y1)
         cr.line_to(x2, y2)
         cr.close_path()
@@ -307,7 +328,7 @@ class Graph(gtk.DrawingArea):
         cr.rectangle(pos_x, pos_y, width, height)
         cr.set_source_rgba(1, 1, 1, 0.8)
         cr.fill_preserve()
-        cr.set_line_width(2)
+        cr.set_line_width(0.5)
         cr.set_source_rgb(*hex2rgb('#000000'))
         cr.stroke()
 
@@ -321,7 +342,7 @@ class Graph(gtk.DrawingArea):
                     y + bullet / 2.0 + text_height / 2.0)
             cr.show_text(keys2txt[key])
 
-        cr.set_line_width(1)
+        cr.set_line_width(0.5)
         x = pos_x + padding
         y = pos_y + padding
         for key in keys:
