@@ -3,6 +3,7 @@
 import httplib
 import logging
 import socket
+import ssl
 import os
 from functools import partial
 from tryton.jsonrpc import ServerProxy, ServerPool, Fault
@@ -42,21 +43,13 @@ def db_list(host, port):
         return result
     except Fault, exception:
         if exception.faultCode == 'AccessDenied':
-            logging.getLogger(__name__).debug(-2)
-            return -2
+            logging.getLogger(__name__).debug('AccessDenied')
+            return []
         else:
             logging.getLogger(__name__).debug(repr(None))
             return None
 
 
-def db_exec(host, port, method, database='', *args):
-    connection = ServerProxy(host, port, database=database)
-    logging.getLogger(__name__).info('common.db.%s(%s)' % (method, args))
-    result = getattr(connection.common.db, method)(*args)
-    logging.getLogger(__name__).debug(repr(result))
-    return result
-
-
 def server_version(host, port):
     try:
         connection = ServerProxy(host, port)
@@ -65,40 +58,32 @@ def server_version(host, port):
         result = connection.common.server.version()
         logging.getLogger(__name__).debug(repr(result))
         return result
-    except (Fault, socket.error):
+    except (Fault, socket.error, ssl.SSLError, ssl.CertificateError), e:
+        logging.getLogger(__name__).error(e)
         return None
 
 
-def login(username, password, host, port, database):
+def login(host, port, database, username, parameters, language=None):
     global CONNECTION, _USER, _USERNAME, _HOST, _PORT, _DATABASE
     global _VIEW_CACHE, _TOOLBAR_CACHE, _KEYWORD_CACHE
-    _VIEW_CACHE = {}
-    _TOOLBAR_CACHE = {}
-    _KEYWORD_CACHE = {}
-    try:
-        if CONNECTION is not None:
-            CONNECTION.close()
-        CONNECTION = ServerPool(host, port, database)
-        logging.getLogger(__name__).info('common.db.login(%s, %s)' %
-            (username, 'x' * 10))
-        with CONNECTION() as conn:
-            result = conn.common.db.login(username, password)
-        logging.getLogger(__name__).debug(repr(result))
-    except socket.error:
-        _USER = None
-        return -1
-    if not result:
-        _USER = None
-        return -2
+    connection = ServerProxy(host, port, database)
+    logging.getLogger(__name__).info('common.db.login(%s, %s, %s)'
+        % (username, 'x' * 10, language))
+    result = connection.common.db.login(username, parameters, language)
+    logging.getLogger(__name__).debug(repr(result))
     _USER = result[0]
     _USERNAME = username
     session = ':'.join(map(str, [username] + result))
+    if CONNECTION is not None:
+        CONNECTION.close()
     CONNECTION = ServerPool(host, port, database, session=session)
     _HOST = host
     _PORT = port
     _DATABASE = database
+    _VIEW_CACHE = {}
+    _TOOLBAR_CACHE = {}
+    _KEYWORD_CACHE = {}
     IPCServer(host, port, database).run()
-    return 1
 
 
 def logout():
