@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 "Signal event"
 
 
@@ -31,7 +31,7 @@ class SignalEvent(object):
         for sig in signal:
             i = 0
             while i < len(self.__connects[sig]):
-                if self.__connects[sig][i][2] == key:
+                if self.__connects[sig][i][2] is key:
                     del self.__connects[sig][i]
                 else:
                     i += 1
